import { Component } from '@angular/core';
import * as Diagramming from '@mindfusion/diagramming';
import * as Drawing from '@mindfusion/drawing';
import * as Graphs from '@mindfusion/graphs';

@Component({
  selector: 'fractal-layout',
  templateUrl: './fractal-layout.html'
})
export class FractalLayout {
  diagram: Diagramming.Diagram;
  brushes: Array<string> = ["#9caac6", "#ce0000", "#c0c0c0"];
  zoomFactor: number = 8;

  constructor() {
    this.diagram = new Diagramming.Diagram();
  }

  onRandomTree() {
    this.diagram.clearAll();

    // create the root node
    var rect = new Drawing.Rect(0, 0, 15, 10);
    var node = new Diagramming.ShapeNode(this.diagram);
    var brush = this.brushes[0];
    node.bounds = rect;
    node.brush = brush;
    node.stroke = this.brushes[1];
    this.diagram.addItem(node);

    // add random children
    this.randomTree(node, 5, 4);

    this.applyLayout();
  }

  randomTree(node: Diagramming.DiagramNode, depth: number, minChildren: number) {
    if (depth <= 0)
      return;

    var diagram = node.parent;
    var children = this.randomInt(depth) - 1 + minChildren;
    var brush: any = this.brushes[0];
    while (brush === node.brush)
      brush = this.brushes[1];

    if (diagram.nodes.length < 3 && children < 2)
      children = 2;

    for (var i = 0; i < children; ++i) {
      // create child node
      var rect = new Drawing.Rect(0, 0, 15, 10);
      var child = new Diagramming.ShapeNode(diagram);
      child.bounds = rect;
      child.brush = brush;
      diagram.addItem(child);

      // create a link
      var link = new Diagramming.DiagramLink(diagram, node, child);
      diagram.addItem(link);

      // build child branch
      this.randomTree(child, depth - 1, minChildren);
    }
  }

  applyLayout() {
    var layout = new Graphs.FractalLayout();
    layout.root = this.diagram.nodes[0];
    this.diagram.arrange(layout);
    this.diagram.resizeToFitItems(10);
  }

  randomInt(max: number) {
    return Math.floor(max * Math.random());
  }

  onZoomIn() {
    if (this.zoomFactor > 200) return;
    this.zoomFactor = this.zoomFactor + 10;
  }

  onZoomOut() {
    if (this.zoomFactor < 9) return;
    this.zoomFactor = this.zoomFactor - 10;
  }
}