import { Component, ViewChild, AfterViewInit } from '@angular/core';
import * as Diagramming from '@mindfusion/diagramming';
import * as Drawing from '@mindfusion/drawing';
import * as Graphs from '@mindfusion/graphs';
import { NodeListView } from "@mindfusion/diagramming-angular";

@Component({
  selector: 'org-chart',
  templateUrl: './org-chart.html'
})
export class OrgChart implements AfterViewInit {
  @ViewChild('nodelistview') nodelistview!: NodeListView;
  diagram: Diagramming.Diagram;
  behavior: Diagramming.Behavior = Diagramming.Behavior.DrawLinks;
  nodes: Array<Diagramming.ShapeNode>;
  iconSize: Drawing.Size = new Drawing.Size(60, 60);

  constructor() {
    this.diagram = new Diagramming.Diagram();

    //styling
    var shapeNodeStyle = new Diagramming.Style();
    shapeNodeStyle.brush = { type: 'SolidBrush', color: '#e0e9e9' };
    shapeNodeStyle.stroke = "Orange";
    shapeNodeStyle.fontName = "Verdana";
    shapeNodeStyle.fontSize = 9;
    shapeNodeStyle.nodeEffects = [new Diagramming.GlassEffect()];
    this.diagram.style = (shapeNodeStyle);

    // create the nodes for the nodelistview
    this.nodes = [];
    var node = new Diagramming.ShapeNode(this.diagram);
    node.text = ("text");
    node.shape = ("Ellipse");
    node.pen = ("Gray");
    node.brush = ("White");
    node.bounds = (new Drawing.Rect(0, 0, 48, 48));
    node.enableStyledText = (true);
    node.font = (new Drawing.Font("sans-serif", 12, true));
    node.strokeThickness = (2);
    this.nodes.push(node);

    // add some nodes to the NodeListView
    var svgImages = ["account", "alarm", "book", "calendar", "computer", "key"];
    var svgNode;
    for (var i = 1; i <= svgImages.length; ++i) {
      svgNode = new Diagramming.SvgNode();
      svgNode.transparent = (true);
      var content = new Diagramming.SvgContent();
      content.parse("./assets/" + svgImages[i - 1] + ".svg");
      svgNode.content = content;
      this.nodes.push(svgNode);
    }
  }

  ngAfterViewInit() {
    (this.nodelistview.element.nativeElement.parentElement!).style.height = "auto";
  }

  onLinkCreated(event: any) {
    var link = event.args.link;
    link.baseShape = "";
    link.headShape = "";
    link.strokeThickness = 3.0;
  }

  onNodeCreated(event: any) {
    var node = event.args.node as Diagramming.SvgNode;
    node.transparent = false;
    node.shape = "Ellipse";
    node.stroke = "orange";
    node.strokeThickness = 3;
    node.font = new Drawing.Font("sans-serif", 4);
    node.imagePadding = new Drawing.Thickness(1.5, 1.5, 1.5, 1.5);
  }

  onLayout() {
    var layout = new Graphs.TreeLayout();
    this.diagram.arrange(layout);
  }
}