import React, { useState, useEffect } from 'react';
import Info from './Info';
import * as Drawing from '@mindfusion/drawing';
import * as Diagramming from '@mindfusion/diagramming';
import { DiagramView } from '@mindfusion/diagramming-react';

const OrgChartNode = Diagramming.CompositeNode.classFromTemplate("OrgChartNode", {
  component: "GridPanel",
  rowDefinitions: ["*"],
  columnDefinitions: ["22", "*"],
  children:
    [
      {
        component: "Rect",
        name: "Background",
        pen: "black",
        brush: "white",
        columnSpan: 2
      },
      {
        component: "Image",
        name: "Image",
        autoProperty: true,
        location: "ceo.png",
        margin: "1",
        imageAlign: "Fit"
      },
      {
        component: "StackPanel",
        orientation: "Vertical",
        gridColumn: 1,
        margin: "1",
        verticalAlignment: "Near",
        children:
          [
            {
              component: "Text",
              name: "Title",
              autoProperty: true,
              text: "title",
              font: "Arial bold"
            },
            {
              component: "Text",
              name: "FullName",
              autoProperty: true,
              text: "full name",
              pen: "blue",
              padding: "1,0,1,0"
            },
            {
              component: "Text",
              name: "Details",
              autoProperty: true,
              text: "details",
              font: "Arial 3"
            }
          ]
      }
    ]
});

function CompositeNodes() {

  const [diagram] = useState(new Diagramming.Diagram());

  useEffect(() => {
    let node1 = new OrgChartNode(diagram);
    node1.bounds = new Drawing.Rect(25, 15, 60, 25);
    node1.title = "CEO";
    node1.fullName = "John Smith";
    node1.details =
      "Our beloved leader. \r\n" +
      "The CEO of this great corporation.";
    node1.image = require('./assets/ceo.png');
    diagram.addItem(node1);

    let node2 = new OrgChartNode(diagram);
    node2.bounds = new Drawing.Rect(25, 55, 60, 25);
    node2.title = "CTO";
    node2.fullName = "Bob Smith";
    node2.details = "The technology chief of this great corporation.";
    node2.image = require('./assets/cto.png');
    diagram.addItem(node2);

    let node3 = new OrgChartNode(diagram);
    node3.bounds = new Drawing.Rect(95, 55, 60, 25);
    node3.title = "HR";
    node3.fullName = "Mary Johnson";
    node3.details = "Human resources and staff development.";
    node3.image = require('./assets/hr.png');
    diagram.addItem(node3);

    let node4 = new OrgChartNode(diagram);
    node4.bounds = new Drawing.Rect(175, 55, 60, 25);
    node4.title = "PR";
    node4.fullName = "Diana Brandson";
    node4.details = "Public relations and media.";
    node4.image = require('./assets/pr.png');
    diagram.addItem(node4);

    let node5 = new OrgChartNode(diagram);
    node5.bounds = new Drawing.Rect(175, 95, 60, 25);
    node5.title = "Media";
    node5.fullName = "Dave Lu";
    node5.details = "Adertising and creative content.";
    node5.image = require('./assets/ad.png');
    diagram.addItem(node5);

    diagram.factory.createDiagramLink(node1, node2);
    diagram.factory.createDiagramLink(node1, node3);
    diagram.factory.createDiagramLink(node1, node4);
    diagram.factory.createDiagramLink(node4, node5);
  }, [diagram]);

  var props = {
    "behavior": Diagramming.Behavior.DrawLinks
  };

  return (
    <div className="App">

      <div className="container">
        <div className="main">
          <DiagramView diagram={diagram} {...props} />
        </div>
        <div className="sidebar">
          <h1>About this sample</h1>
          <p>
            This example shows how to create a custom node class that exposes some new properties
            in addition to the ones defined by DiagramNode and implements its own drawing logic.
          </p>
          <Info />
        </div>
      </div>
      <div className="footer">
        <p>Copyright 2024 MindFusion LLC.</p>
      </div>
    </div>
  );
}



export default CompositeNodes;
