import React, { useState, useRef } from 'react';
import Info from './Info';
import * as Diagramming from '@mindfusion/diagramming';
import { DiagramView, Overview, NodeListView, ZoomControl, Ruler } from '@mindfusion/diagramming-react';


const initNodeListView = ():[Diagramming.DiagramNode[], string[]] => {
  // add some nodes to the NodeListView
  var nodes = [];
  var shapes = ["Actor", "RoundRect", "Triangle", "Decision"];
  for (var i = 0; i < shapes.length; ++i) {
    var node = new Diagramming.ShapeNode();
    node.text = shapes[i];
    node.shape = shapes[i];

    nodes.push(node);
  }
  return [nodes, shapes];
}

function Controls() {
  const [diagram] = useState(new Diagramming.Diagram());
  const [diagramView, setDiagramView] = useState<React.RefObject<typeof DiagramView> | null>(null);
  const diagramViewElement = useRef(null);

  var theme = new Diagramming.Theme();
  var shapeNodeStyle = new Diagramming.Style();
  shapeNodeStyle.brush = ({ type: 'SolidBrush', color: '#e0e9e9' });
  shapeNodeStyle.stroke = ("#7F7F7F");
  shapeNodeStyle.fontName = ("Verdana");
  shapeNodeStyle.fontSize = (4);
  shapeNodeStyle.nodeEffects = ([new Diagramming.GlassEffect()]);
  theme.styles.set("std:ShapeNode", shapeNodeStyle);
  diagram.theme = theme;

  const onControlLoaded = () =>
  {
    setDiagramView(diagramViewElement.current);
  }

  var props = {
    "id": "diagram",
    "linkHeadShapeSize": 2,
    "routeLinks": true,
    "roundedLinks": true,
    "theme": "standard"
  };

  return (
    <div className="App">
      <div className="header">
      </div>

      <div className="container">
        <div className="main">
          <div className="sidebar-left">
            <Overview diagramView={diagramView}></Overview>
            <NodeListView
              nodes={initNodeListView()[0]}
              captions={initNodeListView()[1]}
            ></NodeListView>
          </div>
          <div className="main">
            <ZoomControl diagramView={diagramView} backColor={"transparent"} style={{ position: "absolute", right: 20, top: 30, zIndex: 2 }}></ZoomControl>
            <Ruler style={{ width: "100%" }}>
              <DiagramView
                diagram={diagram}
                {...props}
                style={{ position: "absolute", width: 'auto', height: 'auto', left: 0, right: 0, top: 0, bottom: 0 }}
                onControlLoaded={() => onControlLoaded()}
                ref={diagramViewElement} />
            </Ruler>
          </div>
        </div>
        <div className="sidebar">
          <h1>About this sample</h1>
          <p>This sample demonstrates the auxilliary controls available with React Diagram: NodeListView,
            Overview, ZoomControl and Ruler. The NodeListView implements a list-box control that contains
            DiagramNode objects and allows dragging them to the DiagramView control. The Overview
            provides a scaled-down view of the DiagramView content and lets the user scroll
            the bound view. The ZoomControl lets users zoom and pan the target DiagramView interactively.
            The Ruler control provides horizontal and vertical scales that help users measure and align diagram items.</p>
          <Info />
        </div>
      </div>

      <div className="footer">
        <p>Copyright 2024 MindFusion LLC.</p>
      </div>

    </div>
  );
}

export default Controls;
