﻿import * as Diagramming from '@mindfusion/diagramming';
import * as Controls from '@mindfusion/diagramming-controls';
import ui_blue from '@mindfusion/common-ui/themes/blue.css';
import ui_business from '@mindfusion/common-ui/themes/business.css';
import ui_earth from '@mindfusion/common-ui/themes/earth.css';
import ui_gray from '@mindfusion/common-ui/themes/gray.css';
import ui_green from '@mindfusion/common-ui/themes/green.css';
import ui_light from '@mindfusion/common-ui/themes/light.css';
import ui_pastel from '@mindfusion/common-ui/themes/pastel.css';
import ui_peach from '@mindfusion/common-ui/themes/peach.css';
import ui_standard from '@mindfusion/common-ui/themes/standard.css';
import ui_black from '@mindfusion/common-ui/themes/black.css';
export { ui_blue, ui_business, ui_earth, ui_gray, ui_green, ui_light, ui_pastel, ui_peach, ui_standard, ui_black};

namespace TabbedView {

    let theme;

    let diagramView = Controls.TabbedDiagramView.create(<HTMLCanvasElement>document.getElementById("diagram"));
    diagramView.tabAlignment = Controls.TabAlignment.Top;
    diagramView.showNavigationButtons = true;
    diagramView.showAddButton = true;
    diagramView.allowInplaceEdit = true;
    diagramView.addEventListener(Controls.Events.pageAdded, (sender, args) => {
        setupPage(args.page);
    })
    setupPage(diagramView.selectedPage);

    function setupPage(page) {
        page.theme = theme;
        page.showGrid = true;
        page.gridStyle = Diagramming.GridStyle.Points;
        page.defaultShape = Diagramming.Shapes.Rectangle();
        page.routeLinks = true;
        page.roundedLinks = true;
        page.roundedLinksRadius = 5;
        page.linkHeadShape = Diagramming.ArrowHeads.Triangle();
        page.linkHeadShapeSize = 3;
        page.shadowOffsetX = 2;
        page.shadowOffsetY = 2;
    }

    document.getElementById("tabAlignment").addEventListener("change", (e) => {
        diagramView.tabAlignment = +(<HTMLInputElement>e.target).value;
    });

    document.getElementById("showAddBtn").addEventListener("change", (e) => {
        diagramView.showAddButton = (<HTMLInputElement>e.target).checked;
    });

    document.getElementById("showCloseBtn").addEventListener("change", (e) => {
        diagramView.showTabCloseButtons = (<HTMLInputElement>e.target).checked;
    });

    document.getElementById("showNavBtn").addEventListener("change", (e) => {
        diagramView.showNavigationButtons = (<HTMLInputElement>e.target).checked;
    });

    document.getElementById("theme").onchange = function () {
        var themeId = (<HTMLSelectElement>document.getElementById("theme")).value;
        theme = Diagramming.Theme.fromId(themeId);
        diagramView.setTheme(theme, true);
    }
}